/*
 *  SPDX-FileCopyrightText: 2025 Oliver Beard <olib141@outlook.com>
 *
 *  SPDX-License-Identifier: LGPL-2.0-or-later
 */

#include "abstractnavigablegallerymodel.h"

AbstractNavigableGalleryModel::AbstractNavigableGalleryModel(QObject *parent)
    : AbstractGalleryModel(parent)
{
}
