/****************************************************************************
** Meta object code from reading C++ file 'dirmodelutils.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../koko-26.07.80/src/dirmodelutils.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dirmodelutils.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DirModelUtilsE_t {};
} // unnamed namespace

template <> constexpr inline auto DirModelUtils::qt_create_metaobjectdata<qt_meta_tag_ZN13DirModelUtilsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DirModelUtils",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "homePathChanged",
        "",
        "inHome",
        "QUrl",
        "url",
        "getUrlParts",
        "partialUrlForIndex",
        "index",
        "canBeSimplified",
        "directoryOfUrl",
        "isDirectory",
        "path",
        "fileNameOfUrl",
        "parentOfUrl",
        "mkdir",
        "deleteUrls",
        "QList<QUrl>",
        "urls",
        "restoreUrls",
        "home",
        "pictures",
        "videos"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'homePathChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'inHome'
        QtMocHelpers::MethodData<bool(const QUrl &) const>(7, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'getUrlParts'
        QtMocHelpers::MethodData<QStringList(const QUrl &) const>(10, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'partialUrlForIndex'
        QtMocHelpers::MethodData<QUrl(QUrl, int) const>(11, 6, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 12 },
        }}),
        // Method 'canBeSimplified'
        QtMocHelpers::MethodData<bool(const QUrl &) const>(13, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'directoryOfUrl'
        QtMocHelpers::MethodData<QUrl(const QUrl &) const>(14, 6, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'isDirectory'
        QtMocHelpers::MethodData<bool(const QUrl &) const>(15, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 8, 16 },
        }}),
        // Method 'fileNameOfUrl'
        QtMocHelpers::MethodData<QString(const QString &) const>(17, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'parentOfUrl'
        QtMocHelpers::MethodData<QUrl(const QUrl &) const>(18, 6, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'mkdir'
        QtMocHelpers::MethodData<void(const QUrl &) const>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 16 },
        }}),
        // Method 'deleteUrls'
        QtMocHelpers::MethodData<void(const QList<QUrl> &) const>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Method 'restoreUrls'
        QtMocHelpers::MethodData<void(const QList<QUrl> &) const>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'home'
        QtMocHelpers::PropertyData<QUrl>(24, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'pictures'
        QtMocHelpers::PropertyData<QUrl>(25, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'videos'
        QtMocHelpers::PropertyData<QUrl>(26, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DirModelUtils, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DirModelUtils::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DirModelUtilsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DirModelUtilsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DirModelUtilsE_t>.metaTypes,
    nullptr
} };

void DirModelUtils::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DirModelUtils *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->homePathChanged(); break;
        case 1: { bool _r = _t->inHome((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { QStringList _r = _t->getUrlParts((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 3: { QUrl _r = _t->partialUrlForIndex((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->canBeSimplified((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { QUrl _r = _t->directoryOfUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isDirectory((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->fileNameOfUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QUrl _r = _t->parentOfUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->mkdir((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->deleteUrls((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 11: _t->restoreUrls((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DirModelUtils::*)()>(_a, &DirModelUtils::homePathChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->home(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->pictures(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->videos(); break;
        default: break;
        }
    }
}

const QMetaObject *DirModelUtils::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DirModelUtils::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DirModelUtilsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DirModelUtils::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void DirModelUtils::homePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
