/****************************************************************************
** Meta object code from reading C++ file 'kokoconfig.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../kokoconfig.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kokoconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6ConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto Config::qt_create_metaobjectdata<qt_meta_tag_ZN6ConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Config",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "InitialRunChanged",
        "",
        "IconSizeChanged",
        "SortBehaviorChanged",
        "ImageViewPreviewChanged",
        "SavedFoldersChanged",
        "ImageViewBackgroundColorChanged",
        "ImageViewShowCheckerboardChanged",
        "EnlargeSmallImagesChanged",
        "RememberZoomChanged",
        "NextImageIntervalChanged",
        "LoopImagesChanged",
        "RandomizeImagesChanged",
        "VisibilityChanged",
        "ControlsVisibleChanged",
        "MetadataToDisplayChanged",
        "initialRun",
        "isInitialRunImmutable",
        "defaultInitialRunValue",
        "iconSize",
        "isIconSizeImmutable",
        "defaultIconSizeValue",
        "sortBehavior",
        "isSortBehaviorImmutable",
        "defaultSortBehaviorValue",
        "imageViewPreview",
        "isImageViewPreviewImmutable",
        "defaultImageViewPreviewValue",
        "savedFolders",
        "isSavedFoldersImmutable",
        "imageViewBackgroundColor",
        "isImageViewBackgroundColorImmutable",
        "defaultImageViewBackgroundColorValue",
        "imageViewShowCheckerboard",
        "isImageViewShowCheckerboardImmutable",
        "defaultImageViewShowCheckerboardValue",
        "enlargeSmallImages",
        "isEnlargeSmallImagesImmutable",
        "defaultEnlargeSmallImagesValue",
        "rememberZoom",
        "isRememberZoomImmutable",
        "defaultRememberZoomValue",
        "nextImageInterval",
        "isNextImageIntervalImmutable",
        "defaultNextImageIntervalValue",
        "loopImages",
        "isLoopImagesImmutable",
        "defaultLoopImagesValue",
        "randomizeImages",
        "isRandomizeImagesImmutable",
        "defaultRandomizeImagesValue",
        "visibility",
        "isVisibilityImmutable",
        "defaultVisibilityValue",
        "controlsVisible",
        "isControlsVisibleImmutable",
        "defaultControlsVisibleValue",
        "metadataToDisplay",
        "isMetadataToDisplayImmutable",
        "defaultMetadataToDisplayValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'InitialRunChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'IconSizeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SortBehaviorChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImageViewPreviewChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SavedFoldersChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImageViewBackgroundColorChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImageViewShowCheckerboardChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnlargeSmallImagesChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RememberZoomChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NextImageIntervalChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LoopImagesChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RandomizeImagesChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'VisibilityChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ControlsVisibleChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MetadataToDisplayChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'initialRun'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isInitialRunImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInitialRunValue'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iconSize'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isIconSizeImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIconSizeValue'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sortBehavior'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isSortBehaviorImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSortBehaviorValue'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageViewPreview'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isImageViewPreviewImmutable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultImageViewPreviewValue'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'savedFolders'
        QtMocHelpers::PropertyData<QStringList>(33, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isSavedFoldersImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageViewBackgroundColor'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isImageViewBackgroundColorImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultImageViewBackgroundColorValue'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageViewShowCheckerboard'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isImageViewShowCheckerboardImmutable'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultImageViewShowCheckerboardValue'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enlargeSmallImages'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isEnlargeSmallImagesImmutable'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnlargeSmallImagesValue'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rememberZoom'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isRememberZoomImmutable'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRememberZoomValue'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'nextImageInterval'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isNextImageIntervalImmutable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNextImageIntervalValue'
        QtMocHelpers::PropertyData<int>(49, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'loopImages'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isLoopImagesImmutable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLoopImagesValue'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'randomizeImages'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isRandomizeImagesImmutable'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRandomizeImagesValue'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visibility'
        QtMocHelpers::PropertyData<int>(56, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isVisibilityImmutable'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVisibilityValue'
        QtMocHelpers::PropertyData<int>(58, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'controlsVisible'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isControlsVisibleImmutable'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultControlsVisibleValue'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'metadataToDisplay'
        QtMocHelpers::PropertyData<QStringList>(62, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isMetadataToDisplayImmutable'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMetadataToDisplayValue'
        QtMocHelpers::PropertyData<QStringList>(64, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Config, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Config::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6ConfigE_t>.metaTypes,
    nullptr
} };

void Config::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Config *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->InitialRunChanged(); break;
        case 1: _t->IconSizeChanged(); break;
        case 2: _t->SortBehaviorChanged(); break;
        case 3: _t->ImageViewPreviewChanged(); break;
        case 4: _t->SavedFoldersChanged(); break;
        case 5: _t->ImageViewBackgroundColorChanged(); break;
        case 6: _t->ImageViewShowCheckerboardChanged(); break;
        case 7: _t->EnlargeSmallImagesChanged(); break;
        case 8: _t->RememberZoomChanged(); break;
        case 9: _t->NextImageIntervalChanged(); break;
        case 10: _t->LoopImagesChanged(); break;
        case 11: _t->RandomizeImagesChanged(); break;
        case 12: _t->VisibilityChanged(); break;
        case 13: _t->ControlsVisibleChanged(); break;
        case 14: _t->MetadataToDisplayChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::InitialRunChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::IconSizeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::SortBehaviorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ImageViewPreviewChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::SavedFoldersChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ImageViewBackgroundColorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ImageViewShowCheckerboardChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::EnlargeSmallImagesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::RememberZoomChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::NextImageIntervalChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::LoopImagesChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::RandomizeImagesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::VisibilityChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ControlsVisibleChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::MetadataToDisplayChanged, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->initialRun(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isInitialRunImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultInitialRunValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->iconSize(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isIconSizeImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultIconSizeValue(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->sortBehavior(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isSortBehaviorImmutable(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->defaultSortBehaviorValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->imageViewPreview(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isImageViewPreviewImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultImageViewPreviewValue(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->savedFolders(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isSavedFoldersImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->imageViewBackgroundColor(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isImageViewBackgroundColorImmutable(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->defaultImageViewBackgroundColorValue(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->imageViewShowCheckerboard(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->isImageViewShowCheckerboardImmutable(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->defaultImageViewShowCheckerboardValue(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->enlargeSmallImages(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->isEnlargeSmallImagesImmutable(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->defaultEnlargeSmallImagesValue(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->rememberZoom(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->isRememberZoomImmutable(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->defaultRememberZoomValue(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->nextImageInterval(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->isNextImageIntervalImmutable(); break;
        case 28: *reinterpret_cast<int*>(_v) = _t->defaultNextImageIntervalValue(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->loopImages(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->isLoopImagesImmutable(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->defaultLoopImagesValue(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->randomizeImages(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->isRandomizeImagesImmutable(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->defaultRandomizeImagesValue(); break;
        case 35: *reinterpret_cast<int*>(_v) = _t->visibility(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->isVisibilityImmutable(); break;
        case 37: *reinterpret_cast<int*>(_v) = _t->defaultVisibilityValue(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->controlsVisible(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->isControlsVisibleImmutable(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->defaultControlsVisibleValue(); break;
        case 41: *reinterpret_cast<QStringList*>(_v) = _t->metadataToDisplay(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->isMetadataToDisplayImmutable(); break;
        case 43: *reinterpret_cast<QStringList*>(_v) = _t->defaultMetadataToDisplayValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInitialRun(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setIconSize(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setSortBehavior(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setImageViewPreview(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setSavedFolders(*reinterpret_cast<QStringList*>(_v)); break;
        case 14: _t->setImageViewBackgroundColor(*reinterpret_cast<int*>(_v)); break;
        case 17: _t->setImageViewShowCheckerboard(*reinterpret_cast<bool*>(_v)); break;
        case 20: _t->setEnlargeSmallImages(*reinterpret_cast<bool*>(_v)); break;
        case 23: _t->setRememberZoom(*reinterpret_cast<bool*>(_v)); break;
        case 26: _t->setNextImageInterval(*reinterpret_cast<int*>(_v)); break;
        case 29: _t->setLoopImages(*reinterpret_cast<bool*>(_v)); break;
        case 32: _t->setRandomizeImages(*reinterpret_cast<bool*>(_v)); break;
        case 35: _t->setVisibility(*reinterpret_cast<int*>(_v)); break;
        case 38: _t->setControlsVisible(*reinterpret_cast<bool*>(_v)); break;
        case 41: _t->setMetadataToDisplay(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Config::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Config::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int Config::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void Config::InitialRunChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Config::IconSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Config::SortBehaviorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Config::ImageViewPreviewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Config::SavedFoldersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Config::ImageViewBackgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Config::ImageViewShowCheckerboardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Config::EnlargeSmallImagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Config::RememberZoomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Config::NextImageIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Config::LoopImagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Config::RandomizeImagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Config::VisibilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Config::ControlsVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Config::MetadataToDisplayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
