/****************************************************************************
** Meta object code from reading C++ file 'galleryopenmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../koko-26.07.80/src/models/galleryopenmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'galleryopenmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16GalleryOpenModelE_t {};
} // unnamed namespace

template <> constexpr inline auto GalleryOpenModel::qt_create_metaobjectdata<qt_meta_tag_ZN16GalleryOpenModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GalleryOpenModel",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "modeChanged",
        "",
        "urlToOpenChanged",
        "updated",
        "pathForIndex",
        "QVariant",
        "QModelIndex",
        "index",
        "mode",
        "Mode",
        "urlToOpen",
        "QUrl",
        "OpenNone",
        "OpenFolder",
        "OpenImage",
        "OpenMultiple"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urlToOpenChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updated'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'pathForIndex'
        QtMocHelpers::MethodData<QVariant(const QModelIndex &) const>(9, 6, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 11, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mode'
        QtMocHelpers::PropertyData<enum Mode>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'urlToOpen'
        QtMocHelpers::PropertyData<QUrl>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Mode'
        QtMocHelpers::EnumData<enum Mode>(14, 14, QMC::EnumFlags{}).add({
            {   17, Mode::OpenNone },
            {   18, Mode::OpenFolder },
            {   19, Mode::OpenImage },
            {   20, Mode::OpenMultiple },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<GalleryOpenModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject GalleryOpenModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractNavigableGalleryModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16GalleryOpenModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16GalleryOpenModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16GalleryOpenModelE_t>.metaTypes,
    nullptr
} };

void GalleryOpenModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GalleryOpenModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modeChanged(); break;
        case 1: _t->urlToOpenChanged(); break;
        case 2: _t->updated(); break;
        case 3: { QVariant _r = _t->pathForIndex((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GalleryOpenModel::*)()>(_a, &GalleryOpenModel::modeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GalleryOpenModel::*)()>(_a, &GalleryOpenModel::urlToOpenChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GalleryOpenModel::*)()>(_a, &GalleryOpenModel::updated, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Mode*>(_v) = _t->mode(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->urlToOpen(); break;
        default: break;
        }
    }
}

const QMetaObject *GalleryOpenModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GalleryOpenModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16GalleryOpenModelE_t>.strings))
        return static_cast<void*>(this);
    return AbstractNavigableGalleryModel::qt_metacast(_clname);
}

int GalleryOpenModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractNavigableGalleryModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void GalleryOpenModel::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GalleryOpenModel::urlToOpenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GalleryOpenModel::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
