/****************************************************************************
** Meta object code from reading C++ file 'abstractgallerymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../koko-26.07.80/src/models/abstractgallerymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractgallerymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20AbstractGalleryModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractGalleryModel::qt_create_metaobjectdata<qt_meta_tag_ZN20AbstractGalleryModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractGalleryModel",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Abstract type",
        "titleChanged",
        "",
        "statusChanged",
        "title",
        "status",
        "Status",
        "Unloaded",
        "Loading",
        "Loaded",
        "ItemType",
        "Media",
        "Folder",
        "Collection",
        "ImageRoles",
        "NameRole",
        "FileItemRole",
        "ItemTypeRole",
        "MimeTypeRole",
        "UrlRole",
        "FileCountRole",
        "SizeRole",
        "ModifiedRole",
        "CreatedRole",
        "AccessedRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'title'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(12, 12, QMC::EnumFlags{}).add({
            {   13, Status::Unloaded },
            {   14, Status::Loading },
            {   15, Status::Loaded },
        }),
        // enum 'ItemType'
        QtMocHelpers::EnumData<enum ItemType>(16, 16, QMC::EnumFlags{}).add({
            {   17, ItemType::Media },
            {   18, ItemType::Folder },
            {   19, ItemType::Collection },
        }),
        // enum 'ImageRoles'
        QtMocHelpers::EnumData<enum ImageRoles>(20, 20, QMC::EnumFlags{}).add({
            {   21, ImageRoles::NameRole },
            {   22, ImageRoles::FileItemRole },
            {   23, ImageRoles::ItemTypeRole },
            {   24, ImageRoles::MimeTypeRole },
            {   25, ImageRoles::UrlRole },
            {   26, ImageRoles::FileCountRole },
            {   27, ImageRoles::SizeRole },
            {   28, ImageRoles::ModifiedRole },
            {   29, ImageRoles::CreatedRole },
            {   30, ImageRoles::AccessedRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<AbstractGalleryModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AbstractGalleryModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AbstractGalleryModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AbstractGalleryModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20AbstractGalleryModelE_t>.metaTypes,
    nullptr
} };

void AbstractGalleryModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractGalleryModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->titleChanged(); break;
        case 1: _t->statusChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractGalleryModel::*)()>(_a, &AbstractGalleryModel::titleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractGalleryModel::*)()>(_a, &AbstractGalleryModel::statusChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 1: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractGalleryModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractGalleryModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AbstractGalleryModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int AbstractGalleryModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void AbstractGalleryModel::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AbstractGalleryModel::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
