/****************************************************************************
** Meta object code from reading C++ file 'navigationactions.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../koko-26.07.80/src/navigationactions.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'navigationactions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17NavigationActionsE_t {};
} // unnamed namespace

template <> constexpr inline auto NavigationActions::qt_create_metaobjectdata<qt_meta_tag_ZN17NavigationActionsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NavigationActions",
        "QML.Element",
        "savedFoldersChanged",
        "",
        "tagsChanged",
        "navigate",
        "ModelType",
        "model",
        "QVariant",
        "path",
        "goHome",
        "savedFolders",
        "tags",
        "OpenModel",
        "FolderModel",
        "FavoritesModel",
        "LocationModel",
        "TimeModel",
        "TagsModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'savedFoldersChanged'
        QtMocHelpers::SignalData<void()>(2, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tagsChanged'
        QtMocHelpers::SignalData<void()>(4, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigate'
        QtMocHelpers::SignalData<void(const ModelType, const QVariant)>(5, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Method 'goHome'
        QtMocHelpers::MethodData<void()>(10, 3, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'savedFolders'
        QtMocHelpers::PropertyData<QStringList>(11, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'tags'
        QtMocHelpers::PropertyData<QStringList>(12, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ModelType'
        QtMocHelpers::EnumData<enum ModelType>(6, 6, QMC::EnumFlags{}).add({
            {   13, ModelType::OpenModel },
            {   14, ModelType::FolderModel },
            {   15, ModelType::FavoritesModel },
            {   16, ModelType::LocationModel },
            {   17, ModelType::TimeModel },
            {   18, ModelType::TagsModel },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
    });
    return QtMocHelpers::metaObjectData<NavigationActions, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NavigationActions::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17NavigationActionsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17NavigationActionsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17NavigationActionsE_t>.metaTypes,
    nullptr
} };

void NavigationActions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NavigationActions *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->savedFoldersChanged(); break;
        case 1: _t->tagsChanged(); break;
        case 2: _t->navigate((*reinterpret_cast<std::add_pointer_t<enum ModelType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 3: _t->goHome(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NavigationActions::*)()>(_a, &NavigationActions::savedFoldersChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationActions::*)()>(_a, &NavigationActions::tagsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationActions::*)(const ModelType , const QVariant )>(_a, &NavigationActions::navigate, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->m_savedFolderNames; break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->m_tagNames; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_savedFolderNames, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->savedFoldersChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_tagNames, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->tagsChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *NavigationActions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NavigationActions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17NavigationActionsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int NavigationActions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void NavigationActions::savedFoldersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NavigationActions::tagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NavigationActions::navigate(const ModelType _t1, const QVariant _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
