/****************************************************************************
** Meta object code from reading C++ file 'gallerysortfilterproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../koko-26.07.80/src/models/gallerysortfilterproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gallerysortfilterproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27GallerySortFilterProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto GallerySortFilterProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN27GallerySortFilterProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GallerySortFilterProxyModel",
        "QML.Element",
        "auto",
        "sortBehaviorChanged",
        "",
        "sortModeChanged",
        "sortReversedChanged",
        "filterStringChanged",
        "sortBehavior",
        "SortBehavior",
        "sortMode",
        "SortMode",
        "sortReversed",
        "filterString",
        "Natural",
        "AlphabeticalCaseInsensitive",
        "AlphabeticalCaseSensitive",
        "Name",
        "Size",
        "Modified",
        "Created",
        "Accessed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sortBehaviorChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortModeChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortReversedChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterStringChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sortBehavior'
        QtMocHelpers::PropertyData<enum SortBehavior>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'sortMode'
        QtMocHelpers::PropertyData<enum SortMode>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'sortReversed'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'filterString'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SortBehavior'
        QtMocHelpers::EnumData<enum SortBehavior>(9, 9, QMC::EnumFlags{}).add({
            {   14, SortBehavior::Natural },
            {   15, SortBehavior::AlphabeticalCaseInsensitive },
            {   16, SortBehavior::AlphabeticalCaseSensitive },
        }),
        // enum 'SortMode'
        QtMocHelpers::EnumData<enum SortMode>(11, 11, QMC::EnumFlags{}).add({
            {   17, SortMode::Name },
            {   18, SortMode::Size },
            {   19, SortMode::Modified },
            {   20, SortMode::Created },
            {   21, SortMode::Accessed },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<GallerySortFilterProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject GallerySortFilterProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27GallerySortFilterProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27GallerySortFilterProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27GallerySortFilterProxyModelE_t>.metaTypes,
    nullptr
} };

void GallerySortFilterProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GallerySortFilterProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sortBehaviorChanged(); break;
        case 1: _t->sortModeChanged(); break;
        case 2: _t->sortReversedChanged(); break;
        case 3: _t->filterStringChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GallerySortFilterProxyModel::*)()>(_a, &GallerySortFilterProxyModel::sortBehaviorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GallerySortFilterProxyModel::*)()>(_a, &GallerySortFilterProxyModel::sortModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GallerySortFilterProxyModel::*)()>(_a, &GallerySortFilterProxyModel::sortReversedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GallerySortFilterProxyModel::*)()>(_a, &GallerySortFilterProxyModel::filterStringChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum SortBehavior*>(_v) = _t->sortBehavior(); break;
        case 1: *reinterpret_cast<enum SortMode*>(_v) = _t->sortMode(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->sortReversed(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->filterString(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSortBehavior(*reinterpret_cast<enum SortBehavior*>(_v)); break;
        case 1: _t->setSortMode(*reinterpret_cast<enum SortMode*>(_v)); break;
        case 2: _t->setSortReversed(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setFilterString(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *GallerySortFilterProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GallerySortFilterProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27GallerySortFilterProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int GallerySortFilterProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void GallerySortFilterProxyModel::sortBehaviorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GallerySortFilterProxyModel::sortModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GallerySortFilterProxyModel::sortReversedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void GallerySortFilterProxyModel::filterStringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
