/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<controller.h>)
#  include <controller.h>
#endif
#if __has_include(<devicepixelratiohelper.h>)
#  include <devicepixelratiohelper.h>
#endif
#if __has_include(<dirmodelutils.h>)
#  include <dirmodelutils.h>
#endif
#if __has_include(<displaycolorspace.h>)
#  include <displaycolorspace.h>
#endif
#if __has_include(<exiv2extractor.h>)
#  include <exiv2extractor.h>
#endif
#if __has_include(<filedialoghelper.h>)
#  include <filedialoghelper.h>
#endif
#if __has_include(<fileinfo.h>)
#  include <fileinfo.h>
#endif
#if __has_include(<filemenumanager.h>)
#  include <filemenumanager.h>
#endif
#if __has_include(<kokoconfig.h>)
#  include <kokoconfig.h>
#endif
#if __has_include(<kokostateconfig.h>)
#  include <kokostateconfig.h>
#endif
#if __has_include(<navigationactions.h>)
#  include <navigationactions.h>
#endif
#if __has_include(<notificationmanager.h>)
#  include <notificationmanager.h>
#endif
#if __has_include(<printerhelper.h>)
#  include <printerhelper.h>
#endif
#if __has_include(<resizehelper.h>)
#  include <resizehelper.h>
#endif
#if __has_include(<vectorimage.h>)
#  include <vectorimage.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_koko()
{
    qmlRegisterModule("org.kde.koko", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Config>("org.kde.koko", 254);
    qmlRegisterTypesAndRevisions<Controller>("org.kde.koko", 254);
    qmlRegisterTypesAndRevisions<DevicePixelRatioHelper>("org.kde.koko", 254);
    qmlRegisterTypesAndRevisions<DirModelUtils>("org.kde.koko", 254);
    qmlRegisterTypesAndRevisions<DisplayColorSpace>("org.kde.koko", 254);
    qmlRegisterTypesAndRevisions<Exiv2Extractor>("org.kde.koko", 254);
    qmlRegisterTypesAndRevisions<ExivFilterModel>("org.kde.koko", 254);
    qmlRegisterTypesAndRevisions<FileDialogHelper>("org.kde.koko", 254);
    qmlRegisterTypesAndRevisions<FileInfo>("org.kde.koko", 254);
    qmlRegisterEnum<FileInfo::Status>("FileInfo::Status");
    qmlRegisterEnum<FileInfo::Type>("FileInfo::Type");
    qmlRegisterTypesAndRevisions<FileMenuManager>("org.kde.koko", 254);
    QMetaType::fromType<KConfigSkeleton *>().id();
    QMetaType::fromType<KCoreConfigSkeleton *>().id();
    qmlRegisterEnum<KCoreConfigSkeleton::DisambiguateConstructor>("KCoreConfigSkeleton::DisambiguateConstructor");
    qmlRegisterTypesAndRevisions<NavigationActions>("org.kde.koko", 254);
    qmlRegisterEnum<NavigationActions::ModelType>("NavigationActions::ModelType");
    qmlRegisterTypesAndRevisions<NotificationManager>("org.kde.koko", 254);
    qmlRegisterTypesAndRevisions<PrinterHelper>("org.kde.koko", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<ResizeHelper>("org.kde.koko", 254);
    qmlRegisterTypesAndRevisions<State>("org.kde.koko", 254);
    qmlRegisterTypesAndRevisions<VectorImage>("org.kde.koko", 254);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.koko", 254);
    qmlRegisterEnum<VectorImage::Status>("VectorImage::Status");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.koko", 254, 254);
}

static const QQmlModuleRegistration orgkdekokoRegistration("org.kde.koko", qml_register_types_org_kde_koko);
