/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<abstractgallerymodel.h>)
#  include <abstractgallerymodel.h>
#endif
#if __has_include(<abstractnavigablegallerymodel.h>)
#  include <abstractnavigablegallerymodel.h>
#endif
#if __has_include(<galleryfavoritesmodel.h>)
#  include <galleryfavoritesmodel.h>
#endif
#if __has_include(<galleryfoldermodel.h>)
#  include <galleryfoldermodel.h>
#endif
#if __has_include(<gallerylocationmodel.h>)
#  include <gallerylocationmodel.h>
#endif
#if __has_include(<galleryopenmodel.h>)
#  include <galleryopenmodel.h>
#endif
#if __has_include(<gallerysortfilterproxymodel.h>)
#  include <gallerysortfilterproxymodel.h>
#endif
#if __has_include(<gallerytagsmodel.h>)
#  include <gallerytagsmodel.h>
#endif
#if __has_include(<gallerytimemodel.h>)
#  include <gallerytimemodel.h>
#endif
#if __has_include(<imagestorage.h>)
#  include <imagestorage.h>
#endif
#if __has_include(<mediaviewfiltermodel.h>)
#  include <mediaviewfiltermodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_photos_models()
{
    qmlRegisterModule("org.kde.photos.models", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AbstractGalleryModel>("org.kde.photos.models", 254);
    qmlRegisterEnum<AbstractGalleryModel::Status>("AbstractGalleryModel::Status");
    qmlRegisterEnum<AbstractGalleryModel::ItemType>("AbstractGalleryModel::ItemType");
    qmlRegisterEnum<AbstractGalleryModel::ImageRoles>("AbstractGalleryModel::ImageRoles");
    qmlRegisterTypesAndRevisions<AbstractNavigableGalleryModel>("org.kde.photos.models", 254);
    qmlRegisterTypesAndRevisions<GalleryFavoritesModel>("org.kde.photos.models", 254);
    qmlRegisterTypesAndRevisions<GalleryFolderModel>("org.kde.photos.models", 254);
    qmlRegisterTypesAndRevisions<GalleryLocationModel>("org.kde.photos.models", 254);
    qmlRegisterTypesAndRevisions<GalleryOpenModel>("org.kde.photos.models", 254);
    qmlRegisterEnum<GalleryOpenModel::Mode>("GalleryOpenModel::Mode");
    qmlRegisterTypesAndRevisions<GallerySortFilterProxyModel>("org.kde.photos.models", 254);
    qmlRegisterEnum<GallerySortFilterProxyModel::SortBehavior>("GallerySortFilterProxyModel::SortBehavior");
    qmlRegisterEnum<GallerySortFilterProxyModel::SortMode>("GallerySortFilterProxyModel::SortMode");
    qmlRegisterTypesAndRevisions<GalleryTagsModel>("org.kde.photos.models", 254);
    qmlRegisterTypesAndRevisions<GalleryTimeModel>("org.kde.photos.models", 254);
    qmlRegisterTypesAndRevisions<ImageStorage>("org.kde.photos.models", 254);
    qmlRegisterEnum<ImageStorage::TimeGroup>("ImageStorage::TimeGroup");
    qmlRegisterEnum<ImageStorage::LocationGroup>("ImageStorage::LocationGroup");
    qmlRegisterEnum<ImageStorage::QueryType>("ImageStorage::QueryType");
    qmlRegisterTypesAndRevisions<MediaViewFilterModel>("org.kde.photos.models", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.photos.models", 254, 254);
}

static const QQmlModuleRegistration orgkdephotosmodelsRegistration("org.kde.photos.models", qml_register_types_org_kde_photos_models);
